==> CloudClientStandardAWS_v2.0.0.zip: com.clustercontrol.cloud.base_2.0.0/com/clustercontrol/cloud/presenter/CreateCloudInstanceRequest.java <==
package com.clustercontrol.cloud.presenter;

import java.util.List;

import com.clustercontrol.cloud.commons.util.annotation.Export;
import com.clustercontrol.cloud.commons.util.annotation.Import;
import com.clustercontrol.cloud.resources.Tag;

public class CreateCloudInstanceRequest {
    protected String flavor;
    protected String imageId;
    protected String zone;
    protected String description;
    protected String facilityId;
    protected String facilityName;
    protected String nodeName;
    protected Boolean replaceNode;
    protected String instanceDetail;
    protected List<Tag> tags;
    
    @Export
	public String getFlavor() {
		return flavor;
	}
    
    @Import
	public void setFlavor(String flavor) {
		this.flavor = flavor;
	}
    
    @Export
	public String getImageId() {
		return imageId;
	}
	
    @Import
	public void setImageId(String imageId) {
		this.imageId = imageId;
	}
    
    @Export
	public String getZone() {
		return zone;
	}
	
    @Import
	public void setZone(String zone) {
		this.zone = zone;
	}
    
    @Export
	public String getDescription() {
		return description;
	}
	
    @Import
	public void setDescription(String description) {
		this.description = description;
	}
    
    @Export
	public String getFacilityId() {
		return facilityId;
	}
	
    @Import
	public void setFacilityId(String facilityId) {
		this.facilityId = facilityId;
	}
    
    @Export
	public String getFacilityName() {
		return facilityName;
	}
	
    @Import
	public void setFacilityName(String facilityName) {
		this.facilityName = facilityName;
	}
    
    @Export
	public String getNodeName() {
		return nodeName;
	}
    
    @Import
	public void setNodeName(String nodeName) {
		this.nodeName = nodeName;
	}
    
    @Export
	public Boolean getReplaceNode() {
		return replaceNode;
	}
    @Import
	public void setReplaceNode(Boolean replaceNode) {
		this.replaceNode = replaceNode;
	}
    
    @Export
	public String getInstanceDetail() {
		return instanceDetail;
	}
    
    @Import
	public void setInstanceDetail(String instanceDetail) {
		this.instanceDetail = instanceDetail;
	}
    
    @Export
	public List<Tag> getTags() {
		return tags;
	}
    
    @Import
	public void setTags(List<Tag> tags) {
		this.tags = tags;
	}
}

==> CloudClientStandardAWS_v2.0.1.zip: com.clustercontrol.cloud.base_2.0.1/com/clustercontrol/cloud/presenter/CreateCloudInstanceRequest.java <==
/*
Copyright (C) 2013 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.
 */
package com.clustercontrol.cloud.presenter;

import java.util.List;

import com.clustercontrol.cloud.commons.util.annotation.Export;
import com.clustercontrol.cloud.commons.util.annotation.Import;
import com.clustercontrol.cloud.resources.Tag;

public class CreateCloudInstanceRequest {
    protected String flavor;
    protected String imageId;
    protected String zone;
    protected String description;
    protected String facilityId;
    protected String facilityName;
    protected String nodeName;
    protected Boolean replaceNode;
    protected String instanceDetail;
    protected List<Tag> tags;
    
    @Export
	public String getFlavor() {
		return flavor;
	}
    
    @Import
	public void setFlavor(String flavor) {
		this.flavor = flavor;
	}
    
    @Export
	public String getImageId() {
		return imageId;
	}
	
    @Import
	public void setImageId(String imageId) {
		this.imageId = imageId;
	}
    
    @Export
	public String getZone() {
		return zone;
	}
	
    @Import
	public void setZone(String zone) {
		this.zone = zone;
	}
    
    @Export
	public String getDescription() {
		return description;
	}
	
    @Import
	public void setDescription(String description) {
		this.description = description;
	}
    
    @Export
	public String getFacilityId() {
		return facilityId;
	}
	
    @Import
	public void setFacilityId(String facilityId) {
		this.facilityId = facilityId;
	}
    
    @Export
	public String getFacilityName() {
		return facilityName;
	}
	
    @Import
	public void setFacilityName(String facilityName) {
		this.facilityName = facilityName;
	}
    
    @Export
	public String getNodeName() {
		return nodeName;
	}
    
    @Import
	public void setNodeName(String nodeName) {
		this.nodeName = nodeName;
	}
    
    @Export
	public Boolean getReplaceNode() {
		return replaceNode;
	}
    @Import
	public void setReplaceNode(Boolean replaceNode) {
		this.replaceNode = replaceNode;
	}
    
    @Export
	public String getInstanceDetail() {
		return instanceDetail;
	}
    
    @Import
	public void setInstanceDetail(String instanceDetail) {
		this.instanceDetail = instanceDetail;
	}
    
    @Export
	public List<Tag> getTags() {
		return tags;
	}
    
    @Import
	public void setTags(List<Tag> tags) {
		this.tags = tags;
	}
}
